@@ -4,6 +4,7 @@ AutoTool implementation for the Solana Agent system.
 This module provides the base AutoTool class that implements the Tool interface
 and can be extended to create custom tools.
 """
+
 from typing import Dict, Any
 
 from solana_agent.interfaces.plugins.plugins import Tool
@@ -34,6 +35,8 @@ class AutoTool(Tool):
 
     def configure(self, config: Dict[str, Any]) -> None:
         """Configure the tool with settings from config."""
+        if config is None:
+            raise TypeError("Config cannot be None")
         self._config = config
 
     def get_schema(self) -> Dict[str, Any]:
@@ -41,7 +44,7 @@ class AutoTool(Tool):
         # Override in subclasses
         return {}
 
-    def execute(self, **params) -> Dict[str, Any]:
+    async def execute(self, **params) -> Dict[str, Any]:
         """Execute the tool with the provided parameters."""
         # Override in subclasses
         raise NotImplementedError("Tool must implement execute method")
